@@ -1,22 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2005 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2005 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "fileselectdlg.h"
 
@@ -233,7 +218,7 @@ void FileSelectDlg::accept()
                 msg = i18n("The file <b>%1</b> was found in the completed downloads directory. Do you want to import this file?", tld);
 
             // better ask the user if (s)he wants to delete the already existing data
-            int ret = KMessageBox::questionYesNoList(0, msg, cf, QString());
+            int ret = KMessageBox::questionYesNoList(nullptr, msg, cf, QString());
             if (ret == KMessageBox::Yes) {
                 dn = cn;
             }
@@ -284,7 +269,7 @@ void FileSelectDlg::accept()
     if (pe_ex.count() > 0) {
         QString msg = i18n("You have deselected the following existing files. You will lose all data in these files, are you sure you want to do this?");
         // better ask the user if (s)he wants to delete the already existing data
-        int ret = KMessageBox::warningYesNoList(0, msg, pe_ex, QString(), KGuiItem(i18n("Yes, delete the files")), KGuiItem(i18n("No, keep the files")));
+        int ret = KMessageBox::warningYesNoList(nullptr, msg, pe_ex, QString(), KGuiItem(i18n("Yes, delete the files")), KGuiItem(i18n("No, keep the files")));
         if (ret == KMessageBox::No) {
             for (Uint32 i = 0; i < tc->getNumFiles(); i++) {
                 bt::TorrentFileInterface &file = tc->getTorrentFile(i);
@@ -653,7 +638,7 @@ void FileSelectDlg::setShowFileTree(bool on)
     show_file_tree = on;
     QByteArray hs = m_file_view->header()->saveState();
 
-    filter_model->setSourceModel(0);
+    filter_model->setSourceModel(nullptr);
     delete model;
     if (show_file_tree)
         model = new TorrentFileTreeModel(tc, TorrentFileTreeModel::DELETE_FILES, this);
