@@ -26,13 +26,8 @@ K_PLUGIN_FACTORY_WITH_JSON(ktorrent_logviewer, "ktorrent_logviewer.json", regist
 
 namespace kt
 {
-LogViewerPlugin::LogViewerPlugin(QObject *parent, const QVariantList &)
-    : Plugin(parent)
-    , lv(nullptr)
-    , pref(nullptr)
-    , flags(nullptr)
-    , dock(nullptr)
-    , pos(SEPARATE_ACTIVITY)
+LogViewerPlugin::LogViewerPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : Plugin(parent, data, args)
 {
 }
 
@@ -128,10 +123,5 @@ void LogViewerPlugin::guiUpdate()
         lv->processPending();
 }
 
-bool LogViewerPlugin::versionCheck(const QString &version) const
-{
-    return version == QStringLiteral(VERSION);
-}
-
 }
 #include "logviewerplugin.moc"
