@@ -1,22 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2009 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2009 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "mediaplayeractivity.h"
 
@@ -55,8 +40,8 @@ MediaPlayerActivity::MediaPlayerActivity(CoreInterface *core, KActionCollection
     , ac(ac)
 {
     action_flags = 0;
-    video = 0;
-    play_action = pause_action = stop_action = prev_action = next_action = 0;
+    video = nullptr;
+    play_action = pause_action = stop_action = prev_action = next_action = nullptr;
     fullscreen_mode = false;
 
     media_model = new MediaModel(core, this);
@@ -166,7 +151,7 @@ void MediaPlayerActivity::openVideo()
         tabs->setTabText(idx, path);
         tabs->setCurrentIndex(idx);
     } else {
-        video = new VideoWidget(media_player, ac, 0);
+        video = new VideoWidget(media_player, ac, nullptr);
         connect(video, &VideoWidget::toggleFullScreen, this, &MediaPlayerActivity::setVideoFullScreen);
         int idx = tabs->addTab(video, QIcon::fromTheme(QStringLiteral("video-x-generic")), path);
         tabs->setTabToolTip(idx, i18n("Movie player"));
@@ -186,7 +171,7 @@ void MediaPlayerActivity::closeVideo()
             show_video_action->setChecked(false);
         // tabs->setTabBarHidden(true);
         video->deleteLater();
-        video = 0;
+        video = nullptr;
     }
 }
 
@@ -331,7 +316,7 @@ void MediaPlayerActivity::setVideoFullScreen(bool on)
 
     if (on && !fullscreen_mode) {
         tabs->removeTab(tabs->indexOf(video));
-        video->setParent(0);
+        video->setParent(nullptr);
         video->setFullScreen(true);
         video->show();
         fullscreen_mode = true;
