@@ -35,12 +35,9 @@ using namespace bt;
 
 namespace kt
 {
-SearchPlugin::SearchPlugin(QObject *parent, const QVariantList &args)
-    : Plugin(parent)
-    , engines(nullptr)
+SearchPlugin::SearchPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : Plugin(parent, data, args)
 {
-    Q_UNUSED(args);
-    pref = nullptr;
 }
 
 SearchPlugin::~SearchPlugin()
@@ -111,11 +108,6 @@ void SearchPlugin::preferencesUpdated()
 {
 }
 
-bool SearchPlugin::versionCheck(const QString &version) const
-{
-    return version == QStringLiteral(VERSION);
-}
-
 }
 
 #include "searchplugin.moc"
